==> mogilefs-client-3.0.0.gem: lib/mogilefs/socket/pure_ruby.rb <==
# -*- encoding: binary -*-
# internal implementation details here, do not rely on them in your code

class MogileFS::Socket < Socket
  include MogileFS::SocketCommon

  def self.start(host, port)
    sock = new(Socket::AF_INET, Socket::SOCK_STREAM, 0)
    begin
      sock.connect_nonblock(sockaddr_in(port, host))
    rescue Errno::EINPROGRESS
    end
    sock.post_init(host, port)
  end

  def self.tcp(host, port, timeout = 5)
    sock = start(host, port)
    unless IO.select(nil, [ sock ], nil, timeout)
      sock.close
      raise MogileFS::Timeout, 'socket connect timeout'
    end
    sock
  end

  def timed_read(len, dst = "", timeout = 5)
    begin
      IO.select([self], nil, nil, timeout) or unreadable_socket!
      return read_nonblock(len, dst)
    rescue Errno::EAGAIN
    rescue EOFError
      return
    end while true
  end

  def timed_peek(len, dst, timeout = 5)
    begin
      IO.select([self], nil, nil, timeout) or unreadable_socket!
      rc = recv_nonblock(len, Socket::MSG_PEEK)
      return rc.empty? ? nil : dst.replace(rc)
    rescue Errno::EAGAIN
    rescue EOFError
      dst.replace("")
      return
    end while true
  end

  def timed_write(buf, timeout = 5)
    written = 0
    expect = buf.bytesize
    begin
      rc = write_nonblock(buf)
      return expect if rc == buf.bytesize
      written += rc

      if buf.respond_to?(:byteslice)
        buf = buf.byteslice(rc, buf.bytesize)
      else
        if buf.respond_to?(:encoding) && buf.encoding != Encoding::BINARY
          buf = buf.dup.force_encoding(Encoding::BINARY)
        end
        buf = buf.slice(rc, buf.bytesize)
      end
    rescue Errno::EAGAIN
      IO.select(nil, [self], nil, timeout) or
        request_truncated!(written, expect)
    end while true
  end
end

==> mogilefs-client-3.5.0.rc1.gem: lib/mogilefs/socket/pure_ruby.rb <==
# -*- encoding: binary -*-
# internal implementation details here, do not rely on them in your code

class MogileFS::Socket < Socket
  include MogileFS::SocketCommon

  def self.start(host, port)
    sock = new(Socket::AF_INET, Socket::SOCK_STREAM, 0)
    begin
      sock.connect_nonblock(sockaddr_in(port, host))
    rescue Errno::EINPROGRESS
    end
    sock.post_init(host, port)
  end

  def self.tcp(host, port, timeout = 5)
    sock = start(host, port)
    unless IO.select(nil, [ sock ], nil, timeout)
      sock.close
      raise MogileFS::Timeout, 'socket connect timeout'
    end
    sock
  end

  def timed_read(len, dst = "", timeout = 5)
    begin
      IO.select([self], nil, nil, timeout) or unreadable_socket!(timeout)
      return read_nonblock(len, dst)
    rescue Errno::EAGAIN
    rescue EOFError
      return
    end while true
  end

  def timed_peek(len, dst, timeout = 5)
    begin
      IO.select([self], nil, nil, timeout) or unreadable_socket!(timeout)
      rc = recv_nonblock(len, Socket::MSG_PEEK)
      return rc.empty? ? nil : dst.replace(rc)
    rescue Errno::EAGAIN
    rescue EOFError
      dst.replace("")
      return
    end while true
  end

  def timed_write(buf, timeout = 5)
    written = 0
    expect = buf.bytesize
    begin
      rc = write_nonblock(buf)
      return expect if rc == buf.bytesize
      written += rc

      if buf.respond_to?(:byteslice)
        buf = buf.byteslice(rc, buf.bytesize)
      else
        if buf.respond_to?(:encoding) && buf.encoding != Encoding::BINARY
          buf = buf.dup.force_encoding(Encoding::BINARY)
        end
        buf = buf.slice(rc, buf.bytesize)
      end
    rescue Errno::EAGAIN
      IO.select(nil, [self], nil, timeout) or
        request_truncated!(written, expect, timeout)
    end while true
  end
end
